// A quick test of using a giant dataset of Jeopardy
// questions.  Put together a simple that first shows
// just the question (answer) and then displays the
// answer (question) too.
//
// The source dataset can be found here:
// https://www.reddit.com/r/datasets/comments/1uyd0t/200000_jeopardy_questions_in_a_json_file

JSONArray qs;
int qnum;
boolean show_answer;

void setup()
{
  size( 720, 480 );
  qs = loadJSONArray( "jeopardy.json" );
  qnum = int( random( qs.size() ) );
  show_answer = false;
}

// A helper function to draw text word-by-word, with
// wrapping.  Still not really enough to guarantee that
// all the text of the question and answer will fit on
// a single screen, but good enough as a test.
float narrowText( String s, float y )
{
  String[] wds = splitTokens( s );
  String line = "";
  for ( int idx = 0; idx < wds.length; ++idx ) {
    if ( line.length() > 0 ) {
      line = line + " ";
    }
    line = line + wds[idx];
    if ( line.length() > 20 ) {
      text( line, width/2, y );
      line = "";
      y += 60;
    }
  }
  if ( line.length() > 0 ) {
    text( line, width/2, y );
    line = "";
    y += 60;
  }
  return y;
}

void draw()
{
  background( #2020a0 );
  textSize( 48 );
  textAlign( CENTER );
  fill( 255 );

  fill( #ffffff );
  float y = narrowText( 
    qs.getJSONObject( qnum ).getString( "question" ), 60 );

  if ( show_answer ) {
    fill( #ffffb0 );
    narrowText( 
      qs.getJSONObject( qnum ).getString( "answer" ), y + 60 );
  }
}

void keyPressed()
{
  if ( !show_answer ) {
    show_answer = true;
  } else {
    qnum = int( random( qs.size() ) );
    show_answer = false;
  }
}