// A searchable salary table where you can type the prefix
// to a last name and the sketch will "Autocomplete", showing
// you all people in the list whose last names start with that
// prefix.

Table table;
String prefix;

void setup()
{
  size( 800, 600 );
  noStroke();
  
  // Read in the CSV file from the hard drive.
  table = loadTable( "pssd_processed.csv", "header" );
 
  textSize( 18 );
  
  // At the start of the sketch, the user hasn't typed
  // anything.  So set the initial "prefix" to the empty
  // string.
  prefix = "";
}

void draw()
{
  background( 255 );
  fill( 0 );
  
  // Only look up names if the prefix typed by the user
  // is non-empty.
  if( prefix.length() > 0 ) {
    // Draw the text of the prefix.
    text( prefix, 10, 24 );
    
    int y = 56;
    // Walk over the table row-by-row.  When you find a
    // row for which the last name starts with the prefix
    // typed in by the user, consider that a hit and 
    // show information about that person.
    for( int idx = 0; idx < table.getRowCount(); ++idx ) {
      String name = table.getString( idx, "Last" );
      // May as well convert the typed prefix to upper case
      // so that we don't have to worry about lower case
      // letters.
      if( name.startsWith( prefix.toUpperCase() ) ) {
        String msg = table.getString( idx, "First" )
          + " " + table.getString( idx, "Last" )
          + " (" + table.getString( idx, "Institution" ) 
          + "): " + table.getFloat( idx, "Salary" );
        text( msg, 10, y );
        y += 25;
        
        if( y > height + 25 ) {
          break;
        }
      }  
    }
  }
}

void keyPressed()
{
  if( keyCode == BACKSPACE ) {
    // If you type the backspace key, remove a letter from the
    // prefix.  Unless the prefix is already empty, in which case
    // don't do anything.
    if( prefix.length() > 0 ) {
      prefix = prefix.substring( 0, prefix.length() - 1 );
    } 
  } else if( Character.isLetter( key ) ) {
    // If you type any other key, just tack it on to the end 
    // of the prefix.
    prefix = prefix + key;
  }
}