// A pretend example of using a web API to get live information
// from a website.  In this case, we retrieve a large volume of
// tweets and display information about them.  But I can't give
// you code that fetches those tweets live at this very moment,
// because that requires a secret API key.  Instead, I've recorded
// a JSON file that provides an adequate example.

// Create a class that represents a single tweet.
class Tweet
{
  String text;
  String sender;
  PImage pic;
  int lmarg;
  int twidth;
  int text_base;

  // The constructor expects you to pass in a JSONObject that came
  // from a Twitter feed.  It knows how to extract all the information
  // that makes up the fields of this class from that object.
  Tweet( JSONObject obj )
  {
    //println( obj.getString( "id_str" ) );
    text = obj.getString( "text" );
    sender = obj.getJSONObject( "user" ).getString( "screen_name" );
    String url = obj.getJSONObject( "user" ).getString( "profile_image_url" );
    pic = loadImage( url );

    if ( pic != null ) {
      lmarg = pic.width + 10;
      text_base = pic.height;
    } else {
      lmarg = 10;
      text_base = 25;
    }
    twidth = width - lmarg - 10;
  }

  void render()
  {
    if ( pic != null ) {
      image( pic, 0, 0 );
    }

    text( sender, lmarg, text_base, twidth );
    text( text, lmarg, text_base + 28, 
      twidth, height - 38 - text_base );
  }
}

Tweet[] tweets;
int index;
int last_update;

void setup()
{
  size( 400, 300 );
  textFont( createFont( "Helvetica", 24 ) );

  tweets = new Tweet[0];

  // Load in a file of sample tweets from the disk.
  JSONObject obj = loadJSONObject( "tweets.json" );
  // Pull out the part we actually care about.
  JSONArray arr = obj.getJSONArray( "statuses" );
  // For each status, create a Tweet object and keep track
  // of it in an array.
  for ( int idx = 0; idx < arr.size(); ++idx ) {
    JSONObject status = arr.getJSONObject( idx );
    if ( status.hasKey( "text" ) ) {
      tweets = (Tweet[])append( tweets, new Tweet( status ) );
    }
  }

  index = 0;
  showTweet( index );
  last_update = millis();
}

void draw()
{
  // Draw the current tweet, update automatically 
  // every ten seconds.
  if ( (millis()-last_update) > 10*1000 ) {
    index = (index + 1) % tweets.length;
    showTweet( index );
    last_update = millis();
  }
}

void showTweet( int index )
{
  background( 255 );
  fill( 0 );
  tweets[index].render();
}